summaryrefslogtreecommitdiffstats
path: root/kmail/kmfilterdlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfilterdlg.cpp')
-rw-r--r--kmail/kmfilterdlg.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kmail/kmfilterdlg.cpp b/kmail/kmfilterdlg.cpp
index b5010cc3..83342d43 100644
--- a/kmail/kmfilterdlg.cpp
+++ b/kmail/kmfilterdlg.cpp
@@ -213,7 +213,7 @@ KMFilterDlg::KMFilterDlg(TQWidget* parent, const char* name, bool popFilter, boo
vbl3->addWidget( mApplyOnForChecked );
vbl3->addStretch( 2 );
- mAccountList = new KListView( adv_w, "accountList" );
+ mAccountList = new TDEListView( adv_w, "accountList" );
mAccountList->addColumn( i18n("Account Name") );
mAccountList->addColumn( i18n("Type") );
mAccountList->setAllColumnsShowFocus( true );
@@ -302,8 +302,8 @@ KMFilterDlg::KMFilterDlg(TQWidget* parent, const char* name, bool popFilter, boo
connect( mConfigureShortcut, TQT_SIGNAL(toggled(bool)),
this, TQT_SLOT(slotConfigureShortcutButtonToggled(bool)) );
- connect( mKeyButton, TQT_SIGNAL( capturedShortcut( const KShortcut& ) ),
- this, TQT_SLOT( slotCapturedShortcutChanged( const KShortcut& ) ) );
+ connect( mKeyButton, TQT_SIGNAL( capturedShortcut( const TDEShortcut& ) ),
+ this, TQT_SLOT( slotCapturedShortcutChanged( const TDEShortcut& ) ) );
connect( mConfigureToolbar, TQT_SIGNAL(toggled(bool)),
this, TQT_SLOT(slotConfigureToolbarButtonToggled(bool)) );
@@ -403,7 +403,7 @@ void KMFilterDlg::slotFilterSelected( KMFilter* aFilter )
const bool configureShortcut = aFilter->configureShortcut();
const bool configureToolbar = aFilter->configureToolbar();
const TQString icon = aFilter->icon();
- const KShortcut shortcut( aFilter->shortcut() );
+ const TDEShortcut shortcut( aFilter->shortcut() );
mApplyOnIn->setChecked( applyOnIn );
mApplyOnForAll->setEnabled( applyOnIn );
@@ -517,12 +517,12 @@ void KMFilterDlg::slotConfigureShortcutButtonToggled( bool aChecked )
}
}
-void KMFilterDlg::slotCapturedShortcutChanged( const KShortcut& sc )
+void KMFilterDlg::slotCapturedShortcutChanged( const TDEShortcut& sc )
{
- KShortcut mySc(sc);
+ TDEShortcut mySc(sc);
if ( mySc == mKeyButton->shortcut() ) return;
// FIXME work around a problem when reseting the shortcut via the shortcut dialog
// somehow the returned shortcut does not evaluate to true in KShortcut::isNull(),
// so we additionally have to check for an empty string
if ( mySc.isNull() || mySc.toString().isEmpty() )
mySc.clear();
@@ -517,12 +517,12 @@ void KMFilterDlg::slotConfigureShortcutButtonToggled( bool aChecked )
if ( mySc == mKeyButton->shortcut() ) return;
// FIXME work around a problem when reseting the shortcut via the shortcut dialog
- // somehow the returned shortcut does not evaluate to true in KShortcut::isNull(),
+ // somehow the returned shortcut does not evaluate to true in TDEShortcut::isNull(),
// so we additionally have to check for an empty string
if ( mySc.isNull() || mySc.toString().isEmpty() )